from setuptools import setup, find_packages


setup(
    name = 'check-palindrome-PS',
    version = '0.0.3',
    description = 'This is palindrome checking function',
    long_description = open('Readme.txt').read(),
    url = 'https://balajibetadur.github.io',
    author = 'Prakash Shelar',
    keywords = ['palindrome','Python palindrome'],
    license = 'MIT',
    packages = ['is_palindrome_PS'],
    install_requres = ['']
)